@@ -1,4 +1,4 @@
-#$Revision: 2222 $$Date: 2005-05-23 11:01:14 -0400 (Mon, 23 May 2005) $$Author: wsnyder $
+#$Revision: 4089 $$Date: 2005-07-27 09:55:32 -0400 (Wed, 27 Jul 2005) $$Author: wsnyder $
 ######################################################################
 #
 # This program is Copyright 2002-2005 by Wilson Snyder.
@@ -34,7 +34,7 @@ use strict;
 
 our $Debug;
 
-our $VERSION = '1.020';
+our $VERSION = '1.030';
 
 ######################################################################
 #### Creators
@@ -121,6 +121,13 @@ sub tgts_name_digest {
     return $self->{tgts_name_digest};
 }
 
+sub runtime_key_digest {
+    my $self = shift;
+    # Internal; create digest based on target names and executable
+    $self->{runtime_key_digest} ||= Make::Cache::Hash::hash (text=>[ $self->tgts_gbl, $self->{cmds_exec} ]);
+    return $self->{runtime_key_digest};
+}
+
 sub deps_data_digest {
     my $self = shift;
     my $hash = $self->deps_fixed_digest;
